@@ -1,20 +1,20 @@
 from __future__ import annotations
 
-import functools
 from dis import Instruction
-from types import FrameType, FunctionType
+from types import FrameType
 from typing import Optional
 
 from crayons import yellow, cyan
 
 from . import utils
+from .basis import ExcInfoType, ExceptionInfo
 from .frame import Frame
 from .utils import pprint, computed_gotos_enabled
 
 _implicit_jump_ops = {
     "BREAK_LOOP",
     "CONTINUE_LOOP",
-    "RAISE_VARARGS",
+    "RAISE_VARARGS",  # maybe we can remove RERAISE and RAISE_VARARGS
     "END_FINALLY",
     "RERAISE",
 }
@@ -39,9 +39,6 @@ PREDICT_MAP = {
 
 COMPUTED_GOTOS_ENABLED = computed_gotos_enabled()
 
-# Will be initialized in FrameLogger's ctor, before it's used.
-log: FunctionType
-
 
 class FrameLogger:
     """Logger for a frame."""
@@ -56,20 +53,25 @@ class FrameLogger:
         self.instructions = instructions
         self.frame = frame
         self.instr_pointer = initial_instr_pointer
-        self.jump_detector = JumpDetector(instructions=self.instructions)
+        self.jump_detector = JumpDetector(
+            instructions=self.instructions, debug_mode=debug_mode
+        )
+        # Maybe we can just store to value_stack.last_exception.
+        self.last_exception = None
         self.debug_mode = debug_mode
 
-        global log
-        log = functools.partial(_debug_log, debug_mode)
+    def handle_exception(self, exc_info: ExcInfoType):
+        # We don't need to care about explicitly raise exceptions because the
+        # corresponding instruction handlers do all the job.
+        if self.instructions[self.instr_pointer].opname in {"RAISE_VARARGS", "RERAISE"}:
+            return
 
-    def update(self, frame: FrameType):
-        """Prints names whose values changed since this function is called last time.
+        self.last_exception = ExceptionInfo(
+            type=exc_info[0], value=exc_info[1], traceback=exc_info[2]
+        )
 
-        This function scans through instructions in the frame the logger belongs to,
-        starting from the last_i recorded last time, and stops before the current
-        last_i. It looks for instructions that are intended to mutate a variable,
-        like "STORE_NAME" and "STORE_ATTR", and prints them.
-        """
+    def handle_instructions(self, frame: FrameType):
+        """Handles recently executed instructions."""
         last_i = frame.f_lasti
 
         # Skips when no instruction has been executed. Note that we should not skip
@@ -146,17 +148,23 @@ class FrameLogger:
                 self.instr_pointer += 2
                 continue
 
-            jumped, jump_location = self.jump_detector.detects_jump(instr, last_i)
-            self.instr_pointer = jump_location if jumped else self.instr_pointer + 2
-            self.frame.log_events(frame, instr, jumped)
+            if self.debug_mode:
+                _log(
+                    f"{cyan('Executed instruction')} at line "
+                    + f"{self.frame.offset_to_lineno[instr.offset]}",
+                    instr,
+                )
 
-            # Debug log
-            log(
-                f"{cyan('Executed instruction')} at line "
-                + f"{self.frame.offset_to_lineno[instr.offset]}",
-                instr,
-            )
-            log(f"{yellow('Current stack:')}", self.frame.value_stack.stack)
+            if self.last_exception:
+                jumped = True
+                jump_location = last_i
+            else:
+                jumped, jump_location = self.jump_detector.detects_jump(instr, last_i)
+            self.instr_pointer = jump_location if jumped else self.instr_pointer + 2
+            self.frame.log_events(frame, instr, jumped, self.last_exception)
+
+            if self.debug_mode:
+                _log(f"{yellow('Current stack:')}", self.frame.value_stack.stack)
 
             # Taking the following code as an example.
             #     for i in range(2):
@@ -190,7 +198,8 @@ class FrameLogger:
                     # Note that instr_pointer has been increased already.
                     opname_next = self.instructions[self.instr_pointer].opname
                     if opname_next in PREDICT_MAP.get(instr.opname, {}):
-                        print(f"Found PREDICT!! {instr.opname} -> {opname_next}")
+                        if self.debug_mode:
+                            print(f"Found PREDICT!! {instr.opname} -> {opname_next}")
                         continue
                 except IndexError:
                     pass
@@ -201,13 +210,15 @@ class FrameLogger:
         # Log InitialValue events that's relevant to the line that's about to be
         # executed, this way we record the value before it's (potentially) modified.
         self.frame.log_initial_value_events(frame, self.instructions[last_i])
+        self.last_exception = None
 
 
 class JumpDetector:
     """Detects jump behavior."""
 
-    def __init__(self, instructions: dict[int, Instruction]):
+    def __init__(self, instructions: dict[int, Instruction], debug_mode):
         self.instructions = instructions
+        self.debug_mode = debug_mode
 
     def detects_jump(self, instr: Instruction, last_i) -> (bool, Optional[int]):
         """
@@ -221,7 +232,6 @@ class JumpDetector:
 
         Returns: (whether jump occurred, jumped-to location)
         """
-
         explicit_jump_target = utils.get_jump_target_or_none(instr)
         implicit_jump_target = last_i if instr.opname in _implicit_jump_ops else None
 
@@ -246,19 +256,21 @@ class JumpDetector:
             # so last_i is 26.
             opname_next = self.instructions[explicit_jump_target].opname
             if opname_next in PREDICT_MAP.get(instr.opname, {}):
-                log(f"Found PREDICT!! {instr.opname} -> {opname_next}")
+                if self.debug_mode:
+                    _log(f"Found PREDICT!! {instr.opname} -> {opname_next}")
                 computed_last_i += 2
 
         if computed_last_i == last_i:
-            log(f"Jumped to instruction at offset: {explicit_jump_target}")
+            if self.debug_mode:
+                _log(f"Jumped to instruction at offset: {explicit_jump_target}")
             return True, explicit_jump_target
         elif implicit_jump_target:
-            log(f"Jumped to instruction at offset: {implicit_jump_target}")
+            if self.debug_mode:
+                _log(f"Jumped to instruction at offset: {implicit_jump_target}")
             return True, implicit_jump_target
 
         return False, None
 
 
-def _debug_log(debug_mode, *msg):
-    if debug_mode:
-        pprint(*msg)
+def _log(*msg):
+    pprint(*msg)
